@@ -3,7 +3,7 @@
 
 var cachedContacts = {};
 
-var usersRightsWindowHeight = 179;
+var usersRightsWindowHeight = 194;
 var usersRightsWindowWidth = 450;
 
 var Contact = {
@@ -12,30 +12,11 @@ var Contact = {
     deleteContactsRequestCount: null
 };
 
-function validateEditorInput(sender) {
-    var errortext = "";
-    var field;
-  
-    field = document.pageform.subject;
-    if (field.value == "")
-        errortext = errortext + labels.error_missingsubject + "\n";
-
-    if (!hasRecipients())
-        errortext = errortext + labels.error_missingrecipients + "\n";
-  
-    if (errortext.length > 0) {
-        alert(labels.error_validationfailed + ":\n"
-              + errortext);
-        return false;
-    }
-    return true;
-}
-
 function openContactsFolder(contactsFolder, reload, idx) {
     if ((contactsFolder && contactsFolder != Contact.currentAddressBook)
         || reload) {
         Contact.currentAddressBook = contactsFolder;
-        var url = URLForFolderID(Contact.currentAddressBook) +
+        var url = URLForFolderID(Contact.currentAddressBook, "Contacts") +
             "/view?noframe=1";
 
         var searchValue = search["value"];
@@ -63,6 +44,7 @@ function openContactsFolder(contactsFolder, reload, idx) {
             document.contactsListAjaxRequest.aborted = true;
             document.contactsListAjaxRequest.abort();
         }
+
         document.contactsListAjaxRequest
             = triggerAjaxRequest(url, contactsListCallback, selection);
     }
@@ -77,6 +59,7 @@ function contactsListCallback(http) {
             var table = $("contactsList");
             var tbody = table.tBodies[0];
             var rows = tbody.getElementsByTagName("TR");
+            var fullView = (table.tHead.rows[0].cells.length > 2);
             var data = [];
             if (http.responseText.length > 0)
                 data = http.responseText.evalJSON(true);
@@ -96,9 +79,11 @@ function contactsListCallback(http) {
                     var cells = row.getElementsByTagName("TD");
                     $(cells[0]).update(contact["c_cn"]);
                     $(cells[1]).update(contact["c_mail"]);
-                    $(cells[2]).update(contact["c_screenname"]);
-                    $(cells[3]).update(contact["c_o"]);
-                    $(cells[4]).update(contact["c_telephonenumber"]);
+                    if (fullView) {
+                        $(cells[2]).update(contact["c_screenname"]);
+                        $(cells[3]).update(contact["c_o"]);
+                        $(cells[4]).update(contact["c_telephonenumber"]);
+                    }
                 }
 
                 // Add extra rows
@@ -111,7 +96,6 @@ function contactsListCallback(http) {
                                             { categories: contact["c_categories"],
                                               contactname: contact["c_cn"] },
                                             tbody);
-                    
                     var cell = createElement("td",
                                              null,
                                              ( "displayName" ),
@@ -119,29 +103,32 @@ function contactsListCallback(http) {
                                              null,
                                              row);
                     cell.appendChild(document.createTextNode(contact["c_cn"]));
+                    cell.title = contact["c_cn"];
 
                     cell = document.createElement("td");
                     row.appendChild(cell);
-                    if (contact["c_mail"])
+                    if (contact["c_mail"]) {
                         cell.appendChild(document.createTextNode(contact["c_mail"]));
+                        cell.title = contact["c_mail"];
+                    }
 
-                    cell = document.createElement("td");
-                    row.appendChild(cell);
-                    if (contact["c_screenname"])
-                        cell.appendChild(document.createTextNode(contact["c_screenname"]));
+                    if (fullView) {
+                        cell = document.createElement("td");
+                        row.appendChild(cell);
+                        if (contact["c_screenname"])
+                            cell.appendChild(document.createTextNode(contact["c_screenname"]));
 
-                    cell = document.createElement("td");
-                    row.appendChild(cell);
-                    if (contact["c_o"])
-                        cell.appendChild(document.createTextNode(contact["c_o"]));
+                        cell = document.createElement("td");
+                        row.appendChild(cell);
+                        if (contact["c_o"])
+                            cell.appendChild(document.createTextNode(contact["c_o"]));
 
-                    cell = document.createElement("td");
-                    row.appendChild(cell);
-                    if (contact["c_telephonenumber"])
-                        cell.appendChild(document.createTextNode(contact["c_telephonenumber"]));
+                        cell = document.createElement("td");
+                        row.appendChild(cell);
+                        if (contact["c_telephonenumber"])
+                            cell.appendChild(document.createTextNode(contact["c_telephonenumber"]));
+                    }
                 }
-
-                configureDraggables();
             }
 
             // Remove unnecessary rows
@@ -180,20 +167,21 @@ function contactsListCallback(http) {
             }
 
             // Restore selection and scroll to first selected node
-            tbody.refreshSelectionByIds();
             var selection = http.callbackData;
-            if (selection) {
+            if (selection && tbody.refreshSelectionByIds(selection) > 0) {
                 for (var i = 0; i < selection.length; i++) {
                     var row = $(selection[i]);
                     if (row) {
                         var rowPosition = row.rowIndex * row.getHeight();
                         if (div.getHeight() < rowPosition)
                             div.scrollTop = rowPosition; // scroll to selected contact
+                        row.selectElement();
                         break;
                     }
                 }
             }
-            
+            else
+                tbody.deselectAll();
         }
         else {
             // No more access to this address book; empty the list
@@ -209,6 +197,8 @@ function contactsListCallback(http) {
                     tBody.removeChild(tBody.rows[i]);
             }
         }
+
+        configureDraggables();
     }
     else
         log ("ajax problem 1: status = " + http.status);
@@ -249,17 +239,6 @@ function onContactContextMenuHide(event) {
     this.stopObserving("contextmenu:hide", onContactContextMenuHide);
 }
 
-function onFolderMenuHide(event) {
-    var topNode = $('d');
-
-    if (topNode.menuSelectedEntry) {
-        topNode.menuSelectedEntry.deselect();
-        topNode.menuSelectedEntry = null;
-    }
-    if (topNode.selectedEntry)
-        topNode.selectedEntry.selectElement();
-}
-
 function _onContactMenuAction(folderItem, action, refresh) {
     var selectedFolders = $("contactFolders").getSelectedNodes();
     var folderId = $(folderItem).readAttribute("folderId");
@@ -299,11 +278,12 @@ function onContactMenuMove(event) {
 
 function onMenuExportContact (event) {
     var selectedFolders = $("contactFolders").getSelectedNodes();
-    var selectedFolderId = $(selectedFolders[0]).readAttribute("id");
-    if (selectedFolderId != "/shared") {
-        var contactIds = $(document.menuTarget).collect(function(row) {
-                                                        return row.getAttribute("id");
-                                                        });
+    var canExport = (selectedFolders[0].getAttribute("owner") != "nobody");
+    if (canExport) {
+        var selectedFolderId = $(selectedFolders[0]).readAttribute("id");
+        var contactIds = document.menuTarget.collect(function(row) {
+                return row.readAttribute("id");
+            });
         var url = ApplicationBaseURL + selectedFolderId + "/export"
           + "?uid=" + contactIds.join("&uid=");
         window.location.href = url;
@@ -406,21 +386,23 @@ function onContactRowDblClick(event) {
 }
 
 function onContactSelectionChange(event) {
+    var contactView = $("contactView");
     if (event) {
         // Update rows selection
         var t = getTarget(event);
         onRowClick(event, t);
     }
-
-    var rows = this.parentNode.getSelectedRowsId();
+    if (contactView) {
+        var rows = this.parentNode.getSelectedRowsId();
   
-    if (rows.length == 1) {
-        var node = $(rows[0]);
-        loadContact(node.getAttribute('id'));
-    }
-    else if (rows.length > 1) {
-        $('contactView').update();
-        Contact.currentContact = null;
+        if (rows.length == 1) {
+            var node = $(rows[0]);
+            loadContact(node.getAttribute('id'));
+        }
+        else if (rows.length > 1) {
+            $('contactView').update();
+            Contact.currentContact = null;
+        }
     }
 }
 
@@ -501,9 +483,6 @@ function onToolbarDeleteSelectedContactsConfirm(dialogId) {
     var contactsList = $('contactsList');
     var rows = contactsList.getSelectedRowsId();
     for (var i = 0; i < rows.length; i++) {
-        var row = $(rows[i]);
-        row.deselect();
-        row.hide();
         delete cachedContacts[Contact.currentAddressBook + "/" + rows[i]];
         var urlstr = (URLForFolderID(Contact.currentAddressBook) + "/"
                       + rows[i] + "/delete");
@@ -521,6 +500,7 @@ function onContactDeleteEventCallback(http) {
                 $("contactView").update();
                 Contact.currentContact = null;
             }
+
             Contact.deleteContactsRequestCount--;
             if (Contact.deleteContactsRequestCount == 0) {
                 var nextRow = row.next("tr");
@@ -532,7 +512,10 @@ function onContactDeleteEventCallback(http) {
                     loadContact(Contact.currentContact);
                 }
             }
-            row.parentNode.removeChild(row);
+            if (row) {
+                row.deselect();
+                row.parentNode.removeChild(row);
+            }
         }
         else if (parseInt(http.status) == 403) {
             var row = $(http.callbackData);
@@ -587,10 +570,11 @@ function newContact(sender) {
 
 function newList(sender) {
     var li = $(Contact.currentAddressBook);
-    if (li.hasClassName("remote"))
-      showAlertDialog(_("You cannot create a list in a shared address book."));
-    else
+    var listEditing = li.getAttribute("list-editing");
+    if (listEditing && listEditing == "available")
       openContactWindow(URLForFolderID(Contact.currentAddressBook) + "/newlist");
+    else
+      showAlertDialog(_("You cannot create a list in a shared address book."));
 
     return false;
 }
@@ -626,10 +610,11 @@ function refreshCurrentFolder() {
     openContactsFolder(Contact.currentAddressBook, true);
 }
 
+/* Only used in UIxMailEditor */
 function onConfirmContactSelection(event) {
     var tag = this.getAttribute("name");
-    var folderLi = $(Contact.currentAddressBook);
-    var currentAddressBookName = folderLi.innerHTML;
+    var folder = $("contactFolder");
+    var currentAddressBookName = folder.textContent;
     var selectorList = null;
     var initialValues = null;
 	
@@ -644,9 +629,8 @@ function onConfirmContactSelection(event) {
         else {
           var cname = '' + rows[i].readAttribute("contactname");
           var email = '' + rows[i].cells[1].innerHTML;
-		
-          window.opener.addContact(tag, currentAddressBookName + '/' + cname,
-                                   cid, cname, email);
+          addContact(tag, currentAddressBookName + '/' + cname,
+                     cid, cname, email);
         }
     }
 
@@ -657,7 +641,7 @@ function onConfirmContactSelection(event) {
 }
 
 function addListToOpener (tag, aBookId, aBookName, listId) {
-    var url = ApplicationBaseURL + "/" + aBookId + "/" + listId + "/properties";
+    var url = UserFolderURL + "Contacts/" + aBookId + "/" + listId + "/properties";
     triggerAjaxRequest (url, addListToOpenerCallback, {
                         "aBookId": aBookId, 
                         "aBookName": aBookName,
@@ -669,8 +653,8 @@ function addListToOpenerCallback (http) {
     var received = http.responseText.evalJSON (true);
     for (var i = 0; i < received.length; i++) {
         var contact = received[i];
-        window.opener.addContact(data.tag, data.aBookName + '/' + contact[1],
-                                   contact[0], contact[1], contact[2]);
+        addContact(data.tag, data.aBookName + '/' + contact[1],
+                   contact[0], contact[1], contact[2]);
     }
 }
 
@@ -724,6 +708,7 @@ function appendAddressBook(name, folder) {
 
         li.setAttribute("id", folder);
         li.setAttribute("owner", owner);
+        li.setAttribute("list-editing", "available");
         li.addClassName("local");
         li.appendChild(document.createTextNode(name
                                                .replace("&lt;", "<", "g")
@@ -764,6 +749,7 @@ function onAddressBookExport(event) {
     window.location.href = url;
 
     event.stop();
+    hideMenu(document.currentPopupMenu);
 }
 
 function onAddressBookImport(event) {
@@ -794,13 +780,21 @@ function hideImportResults () {
 }
 function validateUploadForm () {
     rc = false;
-    if ($("contactsFile").value.length)
+    if ($("contactsFile").value.length) {
+      var btn = jQuery('#uploadSubmit');
+      jQuery('#uploadCancel').fadeOut('fast');
+      btn.addClass("disabled");
+      btn.children('span').text(_('Uploading'));
       rc = true;
+    }
     return rc;
 }
 function uploadCompleted(response) {
     data = response.evalJSON(true);
-
+    jQuery('#uploadCancel').show();
+    var btn = jQuery('#uploadSubmit');
+    btn.removeClass("disabled");
+    btn.children('span').text(_('Upload'));
     var div = $("uploadResults");
     if (data.imported <= 0)
         $("uploadResultsContent").update(_("An error occured while importing contacts."));
@@ -1057,15 +1051,15 @@ function onMenuSharing(event) {
 
     var folders = $("contactFolders");
     var selected = folders.getSelectedNodes()[0];
-    var owner = selected.getAttribute("owner");
-    if (owner == "nobody")
-        showAlertDialog(_("The user rights cannot be edited for this object!"));
-    else {
+    var aclEditing = selected.getAttribute("acl-editing");
+    if (aclEditing && aclEditing == "available") {
         var title = this.innerHTML;
         var url = URLForFolderID(selected.getAttribute("id"));
 
         openAclWindow(url + "/acls", title);
     }
+    else
+        showAlertDialog(_("The user rights cannot be edited for this object!"));
 }
 
 function onAddressBooksMenuPrepareVisibility() {
@@ -1078,30 +1072,55 @@ function onAddressBooksMenuPrepareVisibility() {
         var menu = $("contactFoldersMenu").down("ul");;
         var listElements = menu.childNodesWithTag("li");
         var modifyOption = listElements[0];
+        var newListOption = listElements[3];
         var removeOption = listElements[5];
         var exportOption = listElements[7];
+        var importOption = listElements[8];
         var sharingOption = listElements[listElements.length - 1];
 
         // Disable the "Sharing" and "Modify" options when address book
         // is not owned by user
         if (folderOwner == UserLogin || IsSuperUser) {
-            modifyOption.removeClassName("disabled"); // WARNING: will fail for super users anyway
-            sharingOption.removeClassName("disabled");
+            modifyOption.removeClassName("disabled"); // WARNING: will fail
+                                                      // for super users
+                                                      // anyway
+            var aclEditing = selected[0].getAttribute("acl-editing");
+            if (aclEditing && aclEditing == "available") {
+                sharingOption.removeClassName("disabled");
+            }
+            else {
+                sharingOption.addClassName("disabled");
+            }
         }
         else {
             modifyOption.addClassName("disabled");
             sharingOption.addClassName("disabled");
         }
 
+        var listEditing = selected[0].getAttribute("list-editing");
+        if (listEditing && listEditing == "available") {
+            newListOption.removeClassName("disabled");
+        }
+        else {
+            newListOption.addClassName("disabled");
+        }
+
         /* Disable the "remove" and "export ab" options when address book is
            public */
         if (folderOwner == "nobody") {
             exportOption.addClassName("disabled");
+            importOption.addClassName("disabled");
             removeOption.addClassName("disabled");
         }
         else {
             exportOption.removeClassName("disabled");
-            removeOption.removeClassName("disabled");
+            importOption.removeClassName("disabled");
+            if (selected[0].getAttribute("id") == "/personal") {
+                removeOption.addClassName("disabled");
+            }
+            else {
+                removeOption.removeClassName("disabled");
+            }
         }
 
         return true;
@@ -1161,7 +1180,11 @@ function onContactMenuPrepareVisibility() {
     return true;
 }
 
-function getMenus() {
+var originalGetMenus = null;
+if (typeof getMenus == 'function') {
+    originalGetMenus = getMenus;
+}
+getMenus = function() {
     var menus = {};
     menus["contactFoldersMenu"] = new Array(onAddressBookModify, "-", newContact,
                                             newList, "-",
@@ -1184,6 +1207,12 @@ function getMenus() {
     if (contactMenu)
         contactMenu.prepareVisibility = onContactMenuPrepareVisibility;
    
+    if (originalGetMenus) {
+        var originalMenus = originalGetMenus();
+        if (originalMenus)
+            menus = Object.extend(menus, originalMenus);
+    }
+
     return menus;
 }
 
@@ -1197,18 +1226,9 @@ function configureSelectionButtons() {
     }
 }
 
-function onWindowResize(event) {
-    var handle = $("dragHandle");
-    if (handle)
-        handle.adjust();
-    handle = $("rightDragHandle");
-    if (handle)
-        handle.adjust();
-}
-
 function onDocumentKeydown(event) {
     var target = Event.element(event);
-    if (target.tagName != "INPUT") {
+    if (target.tagName != "INPUT" && target.tagName != "TEXTAREA") {
         var keyCode = event.keyCode;
         if (!keyCode) {
             keyCode = event.charCode;
@@ -1297,23 +1317,37 @@ function initContacts(event) {
         table.multiselect = true;
         var tbody = $(table.tBodies[0]);
         tbody.on("click", onContactSelectionChange);
-        tbody.on("dblclick", onContactRowDblClick);
-        tbody.on("selectstart", listRowMouseDownHandler);
-        tbody.on("contextmenu", onContactContextMenu);
+        if ($("contactView")) {
+            tbody.on("dblclick", onContactRowDblClick);
+            tbody.on("selectstart", listRowMouseDownHandler);
+            tbody.on("contextmenu", onContactContextMenu);
+            resetCategoriesMenu();
+            TableKit.Resizable.init(table, {'trueResize' : true, 'keepWidth' : true});
+        }
         configureSortableTableHeaders(table);
-        TableKit.Resizable.init(table, {'trueResize' : true, 'keepWidth' : true});
-    
-        resetCategoriesMenu();
     }
     
-    onWindowResize.defer();
-    Event.observe(window, "resize", onWindowResize);
-    
+    if (typeof onWindowResize != 'function') {
+        // When loaded from the mail editor, onWindowResize is
+        // already registered
+        onWindowResize = onContactsWindowResize;
+        onWindowResize.defer();
+        Event.observe(window, "resize", onWindowResize);
+    } 
     // Default sort options
     sorting["attribute"] = "c_cn";
     sorting["ascending"] = true;
 }
 
+onContactsWindowResize = function (event) {
+    var handle = $("dragHandle");
+    if (handle)
+        handle.adjust();
+    handle = $("rightDragHandle");
+    if (handle)
+        handle.adjust();
+}
+
 function resetCategoriesMenu() {
     var menu = $("categoriesMenu");
     if (menu) {
@@ -1330,7 +1364,7 @@ function resetCategoriesMenu() {
             var catName = UserDefaults["SOGoContactsCategories"][i];
             if (catName.length > 0) {
                 var menuLI = createElement("li");
-                menuLI.observe("click", onCategoriesMenuItemClick);
+                menuLI.observe("mousedown", onCategoriesMenuItemClick);
                 menuLI.category = catName;
                 menuLI.appendChild(document.createTextNode(catName));
                 menuUL.appendChild(menuLI);
@@ -1431,39 +1465,30 @@ function unsetCategoryOnNode(contactNode, category) {
 }
 
 function configureDraggables() {
-    var mainElement = $("dragDropVisual");
-    Draggables.empty ();
-    
-    if (mainElement == null) {
-        mainElement = new Element ("div", {id: "dragDropVisual"});
-        document.body.appendChild(mainElement);
-        mainElement.absolutize ();
+    if ($("contactFolders")) {
+        var rows = jQuery("tr.vcard");
+        rows.draggable("destroy");
+        rows.draggable({
+                    helper: function (event) { return '<div id="dragDropVisual"></div>'; },
+                    start: startDragging,
+                    drag: whileDragging,
+                    stop: stopDragging,
+                    appendTo: 'body',
+                    cursorAt: { right: 25 },
+                    scroll: false,
+                    distance: 4,
+                    zIndex: 20
+                    });
     }
-    mainElement.hide();
-    
-    new Draggable ("dragDropVisual", 
-                   { handle: "contactsList", 
-                           onStart: startDragging,
-                           onEnd: stopDragging,
-                           onDrag: whileDragging,
-                           scroll: window
-                           }); 
 }
 
 function configureDroppables() {
-    var drops = $$("ul#contactFolders li");
-  
-    Droppables.empty ();
-    drops.each (function (drop) {
-            if (!drop.hasClassName ("remote"))
-                Droppables.add (drop.id, 
-                                { hoverclass: "genericHoverClass",
-                                        onDrop: dropAction
-                                        });
-        });   
+    jQuery("li.local").droppable({
+            hoverClass: 'genericHoverClass',
+                drop: dropAction });
 }
 
-function currentFolderIsRemote () {
+function currentFolderIsRemote() {
     rc = false;
     var selectedFolders = $("contactFolders").getSelectedNodes();
     if (selectedFolders.length > 0) {
@@ -1473,54 +1498,52 @@ function currentFolderIsRemote () {
     return rc;
 }
 
-function startDragging (itm, e) {
-    var target = Event.element(e);
-    if (target.up().up().tagName != "TBODY")
-        return false;
-    
-    var handle = $("dragDropVisual");
+function startDragging(event, ui) {
+    var row = event.target;
+    var handle = ui.helper;
     var contacts = $('contactsList').getSelectedRowsId();
     var count = contacts.length;
-    var row = target.up('TR');
-    
+
     if (count == 0 || contacts.indexOf(row.id) < 0) {
-        onRowClick(e, target);
+        onRowClick(event, $(row.id));
         contacts = $("contactsList").getSelectedRowsId();
         count = contacts.length;
     }
+    handle.html(count);
 
-    handle.update (count);
-    if (e.shiftKey || currentFolderIsRemote()) {
-      handle.addClassName("copy");
+    if (event.shiftKey || currentFolderIsRemote()) {
+      handle.addClass("copy");
     }
     handle.show();
 }
 
-function whileDragging (itm, e) {
-    var handle = $("dragDropVisual");
-    if (e.shiftKey || currentFolderIsRemote ())
-        handle.addClassName ("copy");
-    else if (handle.hasClassName ("copy"))
-        handle.removeClassName ("copy");
+function whileDragging(event, ui) {
+    if (event) {
+        var handle = ui.helper;
+        if (event.shiftKey || currentFolderIsRemote())
+            handle.addClass("copy");
+        else if (handle.hasClass("copy"))
+            handle.removeClass("copy");
+    }
 }
 
-function stopDragging () {
-    var handle = $("dragDropVisual");
+function stopDragging(event, ui) {
+    var handle = ui.helper;
     handle.hide();
-    if (handle.hasClassName ("copy"))
-        handle.removeClassName ("copy");
+    if (handle.hasClass("copy"))
+        handle.removeClass("copy");
 }
 
-function dropAction (dropped, zone, e) {
+function dropAction(event, ui) {
     var action = "move"; 
-    if ($("dragDropVisual").hasClassName ("copy"))
+    if (ui.helper.hasClass("copy"))
         action = "copy";
     else
         $('contactView').update();
-    dropSelectedContacts (action, zone.id.substr (1));
+    dropSelectedContacts(action, this.id.substr(1));
 }
 
-function dropSelectedContacts (action, toId) {
+function dropSelectedContacts(action, toId) {
     var selectedFolders = $("contactFolders").getSelectedNodes();
     if (selectedFolders.length > 0) {
         var contactIds = $('contactsList').getSelectedRowsId();
