@@ -1,5 +1,3 @@
-/* -*- Mode: java; tab-width: 2; c-label-minimum-indentation: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-
 var d;
 
 function onSearchFormSubmit() {
@@ -48,7 +46,7 @@ function addUserLineToTree(tree, parent, line) {
     if (line[4] && !line[4].empty())
         email += ", " + line[4].split("\n").join("; "); // extra contact info
     var icon_card = 'abcard.png';
-    var datatype = 'person';
+    var datatype = 'user';
     if (line[3]) {
         icon_card = 'ablist.png';
         datatype = 'group';
@@ -182,7 +180,7 @@ function addFolderBranchToTree(tree, user, folder, nodeId, subId, isLast) {
         icon += 'tb-mail-addressbook-flat-16x16.png';
     else
         icon += 'calendar-folder-16x16.png';
-    var folderId = user + ":" + folderInfos[1];
+    var folderId = user + ":" + folderInfos[1].substr(1);
     var name = folderInfos[0]; // name has the format "Folername (Firstname Lastname <email>)"
     var pos = name.lastIndexOf(' (');
     if (pos > -1)
@@ -196,7 +194,7 @@ function addFolderBranchToTree(tree, user, folder, nodeId, subId, isLast) {
 }
 
 function addFolderNotFoundNode (tree, nodeId) {
-    var icon = ResourcesURL + '/icon_unread.gif';
+    var icon = ResourcesURL + '/dot.png';
     var node = new Node(1, nodeId, _("No possible subscription"), 0, '#',
                         null, null, '', '', icon, icon);
     node._ls = true;
@@ -259,8 +257,10 @@ function onFolderSearchKeyDown(event) {
 function initUserFoldersWindow() {
     var searchValue = $("searchValue");
     searchValue.observe("keydown", onFolderSearchKeyDown);
-    var addButton = $("addButton");
-    addButton.observe("click", onConfirmFolderSelection);
+
+    $("addButton").observe("click", onConfirmFolderSelection);
+    $("doneButton").observe("click", onCloseButtonClick);
+
     searchValue.focus();
 }
 
