@@ -3,7 +3,6 @@
 var contactSelectorAction = 'mailer-contacts';
 var attachmentCount = 0;
 var MailEditor = {
-    addressBook: null,
     currentField: null,
     selectedIndex: -1,
     delay: 750,
@@ -12,24 +11,21 @@ var MailEditor = {
     textFirstFocus: true
 };
 
-function onContactAdd() {
-    var selector = null;
-    var selectorURL = '?popup=YES&selectorId=mailer-contacts';
- 
-    if (MailEditor.addressBook && MailEditor.addressBook.open && !MailEditor.addressBook.closed)
-        MailEditor.addressBook.focus();
-    else {
-        var urlstr = ApplicationBaseURL 
-            + "../Contacts/"
-            + contactSelectorAction + selectorURL;
-        MailEditor.addressBook = window.open(urlstr, "_blank",
-                                             "width=640,height=400,resizable=1,scrollbars=0");
-        MailEditor.addressBook.selector = selector;
-        MailEditor.addressBook.opener = self;
-        MailEditor.addressBook.focus();
+function onContactAdd(button) {
+    var div = $("contacts");
+    if (div.visible()) {
+        div.hide();
+        $("rightPanel").setStyle({ left: "0px" });
+        $(button).removeClassName("active");
     }
-  
-    return false;
+    else {
+        $("rightPanel").setStyle({ left: $("leftPanel").getStyle("width") });
+        div.show();
+        $(button).addClassName("active");
+    }
+
+    $("hiddenDragHandle").adjust();
+    onWindowResize(null);
 }
 
 function addContact(tag, fullContactName, contactId, contactName, contactEmail) {
@@ -65,6 +61,11 @@ function addContact(tag, fullContactName, contactId, contactName, contactEmail)
     }
 }
 
+function onContactFolderChange(event) {
+    initCriteria();
+    openContactsFolder(this.value);
+}
+
 function mailIsRecipient(mailto) {
     var isRecipient = false;
 
@@ -106,62 +107,60 @@ function insertContact(inputNode, contactName, contactEmail) {
 
 /* mail editor */
 
-function validateEditorInput() {
-    var errortext = "";
-    var field;
-   
-    field = document.pageform.subject;
-    if (field.value == "")
-        errortext = errortext + _("error_missingsubject") + "\n";
-
-    if (!hasRecipients())
-        errortext = errortext + _("error_missingrecipients") + "\n";
-   
-    if (errortext.length > 0) {
-        alert(_("error_validationfailed") + ":\n" + errortext);
-        return false;
+function onValidate(onSuccess) {
+    if (document.pageform.action != "send") {
+        
+        if (!hasRecipients()) {
+            showAlertDialog(_("error_missingrecipients"));
+        }
+        else if (document.pageform.subject.value == "") {
+            showConfirmDialog(_("Warning"), _("error_missingsubject"), onValidateDone.bind(this, onSuccess), null, _("Send anyway"), _("Cancel"));
+        }
+        else {
+            onValidateDone(onSuccess);
+        }
     }
-
-    return true;
 }
 
-function onValidate(event) {
-    var rc = false;
+function onValidateDone(onSuccess) {
+    var input = currentAttachmentInput();
+    if (input)
+        input.parentNode.removeChild(input);
 
-    if (document.pageform.action != "send"
-        && validateEditorInput()) {
-        var input = currentAttachmentInput();
-        if (input)
-            input.parentNode.removeChild(input);
-
-        var toolbar = document.getElementById("toolbar");
-        if (!document.busyAnim)
-            document.busyAnim = startAnimation(toolbar);
-  
-        var lastRow = $("lastRow");
-        lastRow.down("select").name = "popup_last";
+    var toolbar = document.getElementById("toolbar");
+    if (!document.busyAnim)
+        document.busyAnim = startAnimation(toolbar);
     
-        window.shouldPreserve = true;
+    var lastRow = $("lastRow");
+    lastRow.down("select").name = "popup_last";
+    
+    window.shouldPreserve = true;
+    
+    document.pageform.action = "send";
+    
+    AIM.submit($(document.pageform), {'onComplete' : onPostComplete});
+    
+    if (typeof onSuccess == 'function')
+        onSuccess();
 
-        document.pageform.action = "send";
+    disposeDialog();
 
-        AIM.submit($(document.pageform), {'onComplete' : onPostComplete});
-
-        rc = true;
-    }
-
-    return rc;
+    return true;
 }
 
 function onPostComplete(response) {
     if (response && response.length > 0) {
         var jsonResponse = response.evalJSON();
         if (jsonResponse["status"] == "success") {
-            if (window.opener && window.opener.refreshMessage) {
-                window.opener.refreshMessage(jsonResponse["sourceFolder"],
-                                             jsonResponse["messageID"]);
-            }
-            window.close();
+            var p;
+            if (window.frameElement && window.frameElement.id)
+                p = parent;
+            if (window.opener && window.opener.refreshMessage)
+                p = window.opener;
+            if (p && p.refreshMessage)
+                p.refreshMessage(jsonResponse["sourceFolder"],
+                                 jsonResponse["messageID"]);            
+            onCloseButtonClick();
         }
         else {
             var message = jsonResponse["message"];
@@ -174,14 +173,14 @@ function onPostComplete(response) {
         }
     }
     else {
-        window.close();
+        onCloseButtonClick();
     }
 }
 
 function clickedEditorSend() {
-    if (onValidate()) {
-        document.pageform.submit();
-    }
+    onValidate(function() {
+            document.pageform.submit();
+        });
 
     return false;
 }
@@ -355,6 +354,19 @@ function initAddresses() {
         });
 }
 
+/* Overwrite function of MailerUI.js */
+function configureDragHandle() {
+    var handle = $("hiddenDragHandle");
+    if (handle) {
+        handle.addInterface(SOGoDragHandlesInterface);
+        handle.leftMargin = 135; // minimum width
+        handle.leftBlock = $("leftPanel");
+        handle.rightBlock = $("rightPanel");
+        handle.enableRightSafety();
+        handle.observe("handle:dragged", onWindowResize);
+    }
+}
+
 function initMailEditor() {
     if (composeMode != "html" && $("text"))
         $("text").style.display = "block";
@@ -396,6 +408,8 @@ function initMailEditor() {
 
     initializePriorityMenu();
 
+    configureDragHandle();
+
     var composeMode = UserDefaults["SOGoMailComposeMessageType"];
     if (composeMode == "html") {
         CKEDITOR.replace('text',
@@ -405,7 +419,7 @@ function initMailEditor() {
                                'BulletedList', '-', 'Link', 'Unlink', 'Image', 
                                'JustifyLeft','JustifyCenter','JustifyRight',
                                'JustifyBlock','Font','FontSize','-','TextColor',
-                               'BGColor','-','SpellChecker']
+                               'BGColor','-','SpellChecker','Scayt']
                              ],
                              language : localeCode,
 			     scayt_sLang : localeCode
@@ -415,8 +429,11 @@ function initMailEditor() {
             focusCKEditor();
     }
 
+    $("contactFolder").observe("change", onContactFolderChange);
+    
     Event.observe(window, "resize", onWindowResize);
     Event.observe(window, "beforeunload", onMailEditorClose);
+    
     onWindowResize.defer();
 }
 
@@ -459,7 +476,6 @@ function onMenuCheckReturnReceipt(event) {
     else {
         this.removeClassName("_chosen");
     }
-
     var receiptInput = $("receipt");
     receiptInput.value = (enabled ? "true" : "false") ;
 }
@@ -491,12 +507,7 @@ function onRemoveAttachments() {
             list.removeChild(nodes[i]);
         }
         else {
-            var filename = "";
-            var childNodes = nodes[i].childNodes;
-            for (var j = 0; j < childNodes.length; j++) {
-                if (childNodes[j].nodeType == 3)
-                    filename += childNodes[j].nodeValue;
-            }
+            var filename = nodes[i].title;
             var url = "" + window.location;
             var parts = url.split("/");
             parts[parts.length-1] = "deleteAttachment?filename=" + encodeURIComponent(filename);
@@ -568,6 +579,7 @@ function onWindowResize(event) {
     var textarea = document.pageform.text;
     var rowheight = (Element.getHeight(textarea) / textarea.rows);
     var headerarea = $("headerArea");
+    var totalwidth = $("rightPanel").getWidth();
   
     var attachmentsarea = $("attachmentsArea");
     var attachmentswidth = 0;
@@ -585,15 +597,15 @@ function onWindowResize(event) {
     }
   
     // Resize subject field
-    subjectinput.setStyle({ width: (window.width()
+    subjectinput.setStyle({ width: (totalwidth
                                     - $(subjectfield).getWidth()
                                     - attachmentswidth
-                                    - 12) + 'px' });
+                                    - 17) + 'px' });
     // Resize from field
-    $("fromSelect").setStyle({ width: (window.width()
+    $("fromSelect").setStyle({ width: (totalwidth
                                        - $("fromField").getWidth()
                                        - attachmentswidth
-                                       - 10) + 'px' });
+                                       - 15) + 'px' });
 
     // Resize address fields
     var addresslist = $('addressList');
@@ -604,6 +616,7 @@ function onWindowResize(event) {
     textarea.setStyle({ 'top': hr.offsetTop + 'px' });
 
     // Resize the textarea (message content)
+    var offsetTop = $('rightPanel').offsetTop + headerarea.getHeight();
     var composeMode = UserDefaults["SOGoMailComposeMessageType"];
     if (composeMode == "html") {
         var editor = $('cke_text');
@@ -611,42 +624,31 @@ function onWindowResize(event) {
             onWindowResize.defer();
             return;
         }
-        var ck_top = $("cke_top_text");
-        var ck_bottom = $("cke_bottom_text");
-        var content = $("cke_contents_text");
-        var top = hr.offsetTop;
-        var height = Math.floor(window.height() - top - ck_top.getHeight() - ck_bottom.getHeight());
-        height = height - 15;
-        
-        if (Prototype.Browser.IE) {
-            editor.style.width = '';
-            editor.style.height = '';
-        }
-
-        editor.setStyle({ top: (top + 2) + 'px' });
-        content.setStyle({ height: height + 'px' });
+        var height = window.height() - offsetTop;
+        CKEDITOR.instances["text"].resize('100%', height);
     }
     else
-        textarea.rows = Math.floor((window.height() - textarea.offsetTop) / rowheight);
+        textarea.rows = Math.floor((window.height() - offsetTop) / rowheight);
+
+    // Resize search contacts addressbook selector
+    if ($("contacts").visible())
+        $("contactFolder").setStyle({ width: ($("contactsSearch").getWidth() - 10) + "px" });
 }
 
 function onMailEditorClose(event) {
     if (window.shouldPreserve)
         window.shouldPreserve = false;
     else {
-        if (window.opener && window.opener.open && !window.opener.closed) {
-            var url = "" + window.location;
-            var parts = url.split("/");
-            parts[parts.length-1] = "delete";
-            url = parts.join("/");
+        var url = "" + window.location;
+        var parts = url.split("/");
+        parts[parts.length-1] = "delete";
+        url = parts.join("/");
+        if (window.frameElement && window.frameElement.id)
+            parent.deleteDraft(url);
+        else if (window.opener && window.opener.open && !window.opener.closed)
             window.opener.deleteDraft(url);
-        }
     }
 
-    if (MailEditor.addressBook && MailEditor.addressBook.open
-        && !MailEditor.addressBook.closed)
-        MailEditor.addressBook.close();
-
     Event.stopObserving(window, "beforeunload", onMailEditorClose);
 }
 
