@@ -1,7 +1,7 @@
 /* generic.js - this file is part of SOGo
 
    Copyright (C) 2005 SKYRIX Software AG
-   Copyright (C) 2006-2010 Inverse
+   Copyright (C) 2006-2011 Inverse
 
  SOGo is free software; you can redistribute it and/or modify it under
  the terms of the GNU Lesser General Public License as published by the
@@ -48,6 +48,23 @@ var removeFolderRequestCount = 0;
 var emailRE = /^([\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+\.)*[\w\!\#$\%\&\'\*\+\-\/\=\?\^\`{\|\}\~]+@((((([a-z0-9]{1}[a-z0-9\-]{0,62}[a-z0-9]{1})|[a-z])\.)+[a-z]{2,6})|(\d{1,3}\.){3}\d{1,3}(\:\d{1,5})?)$/i;
 
 
+/* This function enables the execution of a wrapper function just before the
+ user callback is executed. The wrapper in question executes "preventDefault"
+ to the event parameter if and only when "this" is a link. The goal of this
+ operation is to prevent links with attached even handlers to be followed,
+ including those with an href set to "#". */
+function clickEventWrapper(functionRef) {
+    function button_clickEventWrapper(event) {
+        if (this.tagName == "A") {
+            preventDefault(event);
+        }
+        return functionRef.apply(this, [event]);
+    }
+
+    return button_clickEventWrapper;
+}
+
+
 function createElement(tagName, id, classes,
                        attributes, htmlAttributes,
                        parentNode) {
@@ -161,46 +178,108 @@ function openUserFolderSelector(callback, type) {
     if (! urlstr.endsWith('/'))
         urlstr += '/';
     urlstr += ("../../" + UserLogin + "/Contacts/userFolders");
-    var w = window.open(urlstr, "_blank",
-                        "width=322,height=250,resizable=1,scrollbars=0,location=0");
-    w.opener = window;
-    window.userFolderCallback = callback;
-    window.userFolderType = type;
-    w.focus();
+
+    var div = $("popupFrame");
+    if (div) {
+        if (!div.hasClassName("small"))
+            div.addClassName("small");
+        var iframe = div.down("iframe");
+        iframe.src = urlstr;
+        iframe.id = "folderSelectorFrame";
+        var bgDiv = $("bgFrameDiv");
+        if (bgDiv) {
+            bgDiv.show();
+        }
+        else {
+            bgDiv = createElement("div", "bgFrameDiv", ["bgMail"]);
+            document.body.appendChild(bgDiv);
+        }
+        div.show();
+    }
+    else {
+        var w = window.open(urlstr, "_blank",
+                            "width=322,height=250,resizable=1,scrollbars=0,location=0");
+        w.opener = window;
+        window.userFolderCallback = callback;
+        window.userFolderType = type;
+        w.focus();
+    }
 }
 
 function openContactWindow(url, wId) {
-    if (!wId)
-        wId = "_blank";
-    else
-        wId = sanitizeWindowName(wId);
+    var div = $("popupFrame");
+    if (div) {
+        if (!div.hasClassName("small"))
+            div.addClassName("small");
+        var iframe = div.down("iframe");
+        iframe.src = url;
+        iframe.id = "contactEditorFrame";
+        var bgDiv = $("bgFrameDiv");
+        if (bgDiv) {
+            bgDiv.show();
+        }
+        else {
+            bgDiv = createElement("div", "bgFrameDiv");
+            document.body.appendChild(bgDiv);
+        }
+        div.show();
 
-    var w = window.open(url, wId,
-                        "width=450,height=530,resizable=0,location=0");
-    w.focus();
+        return div;
+    }
+    else {
+        if (!wId)
+            wId = "_blank";
+        else
+            wId = sanitizeWindowName(wId);
 
-    return w;
+        var w = window.open(url, wId,
+                            "width=450,height=530,resizable=0,location=0");
+        w.focus();
+
+        return w;
+    }
 }
 
 function openMailComposeWindow(url, wId) {
-    var parentWindow = this;
+    var div = $("popupFrame");
+    if (div) {
+        if (div.hasClassName("small"))
+            div.removeClassName("small");
+        var iframe = div.down("iframe");
+        iframe.src = url;
+        iframe.id = "messageCompositionFrame";
+        var bgDiv = $("bgFrameDiv");
+        if (bgDiv) {
+            bgDiv.show();
+        }
+        else {
+            bgDiv = createElement("div", "bgFrameDiv");
+            document.body.appendChild(bgDiv);
+        }
+        div.show();
 
-    if (!wId)
-        wId = "_blank";
-    else
-        wId = sanitizeWindowName(wId);
+        return div;
+    }
+    else {
+        var parentWindow = this;
 
-    if (document.body.hasClassName("popup"))
-        parentWindow = window.opener;
+        if (!wId)
+            wId = "_blank";
+        else
+            wId = sanitizeWindowName(wId);
 
-    var w = parentWindow.open(url, wId,
-                              "width=680,height=520,resizable=1,scrollbars=1,toolbar=0,"
-                              + "location=0,directories=0,status=0,menubar=0"
-                              + ",copyhistory=0");
+        if (document.body.hasClassName("popup"))
+            parentWindow = window.opener;
 
-    w.focus();
+        var w = parentWindow.open(url, wId,
+                                  "width=680,height=520,resizable=1,scrollbars=1,toolbar=0,"
+                                  + "location=0,directories=0,status=0,menubar=0"
+                                  + ",copyhistory=0");
 
-    return w;
+        w.focus();
+
+        return w;
+    }
 }
 
 function openMailTo(senderMailTo) {
@@ -213,11 +292,9 @@ function openMailTo(senderMailTo) {
             sanitizedAddresses.push(sanitizedAddress);
     }
 
-    var mailto = sanitizedAddresses.join(",");
-
-    if (mailto.length > 0)
+    if (sanitizedAddresses.length > 0)
         openMailComposeWindow(ApplicationBaseURL
-                              + "../Mail/compose?mailto=" + encodeURIComponent(mailto)
+                              + "../Mail/compose?mailto=" + encodeURIComponent(Object.toJSON(sanitizedAddresses))
                               + ((subject.length > 0)?"?subject=" + encodeURIComponent(subject):""));
 
     return false; /* stop following the link */
@@ -548,13 +625,12 @@ function onRowClick(event, target) {
     var node = target || getTarget(event);
     var rowIndex = null;
 
-    if (node.tagName != 'TD' && node.tagName != 'LI')
+    if (node.tagName != 'TD' && node.tagName != 'LI' && node.tagName != 'TR')
         node = this;
 
     if (node.tagName == 'TD') {
         node = node.parentNode; // select TR
     }
-
     if (node.tagName == 'TR') {
         var head = $(node).up('table').down('thead');
         rowIndex = node.rowIndex;
@@ -580,7 +656,7 @@ function onRowClick(event, target) {
     else
         // Not a list; stop here
         return true;
-    
+
     var initialSelection = $(node.parentNode).getSelectedNodesId();
     if (initialSelection && initialSelection.length > 0
         && initialSelection.indexOf(node.id) >= 0
@@ -660,7 +736,6 @@ function popupMenu(event, menuId, target) {
                          visibility: "visible" });
 
         document.currentPopupMenu = popup;
-
         $(document.body).observe("mousedown", onBodyClickMenuHandler);
     }
 }
@@ -803,10 +878,17 @@ function toggleLogConsole(event) {
 
 function log(message) {
     if (!logWindow) {
-        logWindow = window;
         try {
-            while (logWindow.opener && logWindow.opener_logMessage)
-                logWindow = logWindow.opener;
+            if (window.frameElement && window.frameElement.id) {
+                logWindow = parent.window;
+                while (logWindow.frameElement && window.frameElement.id)
+                    logWindow = logWindow.parent.window;
+            }
+            else {
+                logWindow = window;
+                while (logWindow.opener && logWindow.opener._logMessage)
+                    logWindow = logWindow.opener;
+            }
         }
         catch(e) {}
     }
@@ -945,8 +1027,8 @@ function popupSearchMenu(event) {
 
         var popup = $(menuId);
         offset = Position.positionedOffset(this);
-        popup.setStyle({ top: this.offsetHeight + "px",
-                         left: (offset[0] + 3) + "px",
+        popup.setStyle({ top: (offset.top + this.getHeight()) + "px",
+                         left: (offset.left + 3) + "px",
                          visibility: "visible" });
 
         document.currentPopupMenu = popup;
@@ -958,6 +1040,9 @@ function setSearchCriteria(event) {
     var searchValue = $("searchValue");
     var searchCriteria = $("searchCriteria");
 
+    if (searchValue.ghostPhrase == searchValue.value)
+        searchValue.value = "";
+
     searchValue.ghostPhrase = this.innerHTML;
     searchCriteria.value = this.getAttribute('id');
 
@@ -975,13 +1060,6 @@ function setSearchCriteria(event) {
     }
 }
 
-function checkSearchValue(event) {
-    var searchValue = $("searchValue");
-
-    if (searchValue.value == searchValue.ghostPhrase)
-        searchValue.value = "";
-}
-
 function configureSearchField() {
     var searchValue = $("searchValue");
 
@@ -1141,7 +1219,7 @@ function subscribeToFolder(refreshCallback, refreshCallbackData) {
     var folderPath = folderData[1];
     if (username != UserLogin) {
         var url = (UserFolderURL + "../" + username
-                   + folderPath + "/subscribe");
+                   + "/" + folderPath + "/subscribe");
         if (document.subscriptionAjaxRequest) {
             document.subscriptionAjaxRequest.aborted = true;
             document.subscriptionAjaxRequest.abort();
@@ -1193,11 +1271,18 @@ function accessToSubscribedFolder(serverFolder) {
 
     var parts = serverFolder.split(":");
     if (parts.length > 1) {
+        var username = parts[0];
         var paths = parts[1].split("/");
-        folder = "/" + parts[0].asCSSIdentifier() + "_" + paths[2];
+        if (username == UserLogin) {
+            folder = paths[1];
+        }
+        else {
+            folder = "/" + username.asCSSIdentifier() + "_" + paths[1];
+        }
     }
-    else
+    else {
         folder = serverFolder;
+    }
 
     return folder;
 }
@@ -1368,6 +1453,8 @@ function initMenus() {
             var menuDIV = $(menuID);
             if (menuDIV)
                 initMenu(menuDIV, menus[menuID]);
+            else
+                log("Can't find menu " + menuID);
         }
     }
 }
@@ -1428,8 +1515,9 @@ function getTopWindow() {
     var topWindow = null;
     var currentWindow = window;
     while (!topWindow) {
-        if (currentWindow.document.body.hasClassName("popup")
-            && currentWindow.opener)
+        if ($(currentWindow.document.body).hasClassName("popup")
+            && currentWindow.opener
+            && currentWindow.opener.getTopWindow)
             currentWindow = currentWindow.opener;
         else
             topWindow = currentWindow;
@@ -1535,6 +1623,23 @@ function onLoadHandler(event) {
     onFinalLoadHandler();
 }
 
+function onCloseButtonClick(event) {
+    if (event)
+        Event.stop(event);
+
+    if (window.frameElement && window.frameElement.id) {
+        jQuery(parent$("bgFrameDiv")).fadeOut('fast');
+        var div = parent$("popupFrame");
+        div.hide();
+        div.down("iframe").src = "/SOGo/loading";
+    }
+    else {
+        window.close();
+    }
+
+    return false;
+}
+
 function onBodyClickContextMenu(event) {
     var target = $(event.target);
     if (!(target
@@ -1562,12 +1667,29 @@ function onLinkBannerClick() {
 
 function onPreferencesClick(event) {
     var urlstr = UserFolderURL + "preferences";
-    var w = window.open(urlstr, "_blank",
-                        "width=580,height=450,resizable=1,scrollbars=0,location=0");
-    w.opener = window;
-    w.focus();
-
-    preventDefault(event);
+    var div = $("popupFrame");
+    if (div) {
+        if (div.hasClassName("small"))
+            div.removeClassName("small");
+        var iframe = div.down("iframe");
+        iframe.src = urlstr;
+        iframe.id = "preferencesFrame";
+        var bgDiv = $("bgFrameDiv");
+        if (bgDiv) {
+            bgDiv.show();
+        }
+        else {
+            bgDiv = createElement("div", "bgFrameDiv", ["bgMail"]);
+            document.body.appendChild(bgDiv);
+        }
+        div.show(); //setStyle({display: "block"});
+    }
+    else {
+        var w = window.open(urlstr, "SOGoPreferences",
+                            "width=580,height=476,resizable=1,scrollbars=0,location=0");
+        w.opener = window;
+        w.focus();
+    }
 }
 
 function configureLinkBanner() {
@@ -1584,7 +1706,7 @@ function configureLinkBanner() {
         link = $("preferencesBannerLink");
         if (link) {
             link.observe("mousedown", listRowMouseDownHandler);
-            link.observe("click", onPreferencesClick);
+            link.observe("click", clickEventWrapper(onPreferencesClick));
         }
         link = $("consoleBannerLink");
         if (link) {
@@ -1688,7 +1810,16 @@ function onFinalLoadHandler(event) {
 }
 
 function parent$(element) {
-    return this.opener.document.getElementById(element);
+    var div = $("popupFrame");
+
+    if (div)
+        p = parent.document;
+    else if (this.opener)
+        p = this.opener.document;
+    else
+        p = null;
+
+    return (p ? p.getElementById(element) : null);
 }
 
 /* stubs */
@@ -1710,12 +1841,7 @@ function _(key) {
         value = labels[key];
     }
     else {
-        var topWindow = null;
-        if (!topWindow) {
-            topWindow = window;
-            while (topWindow.opener)
-                topWindow = topWindow.opener;
-        }
+        var topWindow = getTopWindow();
         if (topWindow && topWindow.clabels && topWindow.clabels[key])
             value = topWindow.clabels[key];
     }
@@ -1819,8 +1945,9 @@ function createButton(id, caption, action) {
         var span = createElement("span", null, null, null, null, newButton);
         span.appendChild(document.createTextNode(caption));
     }
-    if (action)
-        newButton.on("click", action);
+    if (action) {
+        newButton.on("click", clickEventWrapper(action));
+    }
 
     return newButton;
 }
@@ -1851,18 +1978,18 @@ function _showAlertDialog(label) {
         document.body.appendChild(dialog);
         dialogs[label] = dialog;
     }
-    dialog.appear({ duration: 0.2 });
+    jQuery(dialog).fadeIn('fast');
 }
 
-function showConfirmDialog(title, label, callbackYes, callbackNo) {
+function showConfirmDialog(title, label, callbackYes, callbackNo, yesLabel, noLabel) {
     var div = $("bgDialogDiv");
     if (div && div.visible() && div.getOpacity() > 0)
-        dialogsStack.push(_showConfirmDialog.bind(this, title, label, callbackYes, callbackNo));
+        dialogsStack.push(_showConfirmDialog.bind(this, title, label, callbackYes, callbackNo, yesLabel, noLabel));
     else
-        _showConfirmDialog(title, label, callbackYes, callbackNo);
+        _showConfirmDialog(title, label, callbackYes, callbackNo, yesLabel, noLabel);
 }
 
-function _showConfirmDialog(title, label, callbackYes, callbackNo) {
+function _showConfirmDialog(title, label, callbackYes, callbackNo, yesLabel, noLabel) {
     var key = title;
     if (Object.isElement(label)) key += label.allTextContent();
     else key += label;
@@ -1879,8 +2006,8 @@ function _showConfirmDialog(title, label, callbackYes, callbackNo) {
     }
     else {
         var fields = createElement("p");
-        fields.appendChild(createButton(null, _("Yes"), callbackYes));
-        fields.appendChild(createButton(null, _("No"), callbackNo || disposeDialog));
+        fields.appendChild(createButton(null, _(yesLabel || "Yes"), callbackYes));
+        fields.appendChild(createButton(null, _(noLabel || "No"), callbackNo || disposeDialog));
         dialog = createDialog(null,
                               title,
                               label,
@@ -1889,7 +2016,7 @@ function _showConfirmDialog(title, label, callbackYes, callbackNo) {
         document.body.appendChild(dialog);
         dialogs[key] = dialog;
     }
-    dialog.appear({ duration: 0.2 });
+    jQuery(dialog).fadeIn('fast');
 }
 
 function showPromptDialog(title, label, callback, defaultValue) {
@@ -1928,8 +2055,7 @@ function _showPromptDialog(title, label, callback, defaultValue) {
         document.body.appendChild(dialog);
         dialogs[title+label] = dialog;
     }
-    dialog.appear({ duration: 0.2,
-                    afterFinish: function () { dialog.down("input").focus(); } });
+    jQuery(dialog).fadeIn('fast', function () { dialog.down("input").focus(); });
 }
 
 function showSelectDialog(title, label, options, button, callbackFcn, callbackArg, defaultValue) {
@@ -1975,13 +2101,52 @@ function _showSelectDialog(title, label, options, button, callbackFcn, callbackA
     }
     if (defaultValue)
 	defaultOption = dialog.down('option[value="'+defaultValue+'"]').selected = true;
-    dialog.appear({ duration: 0.2 });
+    jQuery(dialog).fadeIn('fast');
+}
+
+function showAuthenticationDialog(label, callback) {
+    var div = $("bgDialogDiv");
+    if (div && div.visible() && div.getOpacity() > 0)
+        dialogsStack.push(_showAuthenticationDialog.bind(this, label, callback));
+    else
+        _showAuthenticationDialog(label, callback);
+}
+
+function _showAuthenticationDialog(label, callback) {
+    var dialog = dialogs[label];
+    if (dialog) {
+        $("bgDialogDiv").show();
+        var inputs = dialog.getElementsByTagName("input");
+        for (var i = 0; i < inputs.length; i++) {
+            inputs[i].value = "";
+        }
+    }
+    else {
+        var fields = createElement("p", null, ["prompt"]);
+	fields.appendChild(document.createTextNode(_("Username:")));
+        var un_input = createElement("input", null, "textField",
+				     { type: "text", "value": "" });
+	fields.appendChild(un_input);
+	fields.appendChild(document.createTextNode(_("Password:")));
+        var pw_input = createElement("input", null, "textField",
+			             { type: "password", "value": "" });
+	fields.appendChild(pw_input);
+        function callbackWrapper() {
+            callback(un_input.value, pw_input.value);
+        }
+        fields.appendChild(createButton(null, _("OK"), callbackWrapper));
+	fields.appendChild(createButton(null, _("Cancel"), disposeDialog));
+        dialog = createDialog(null, label, null, fields, "none");
+        document.body.appendChild(dialog);
+        dialogs[label] = dialog;
+    }
+    jQuery(dialog).fadeIn('fast', function () { dialog.down("input").focus(); });
 }
 
 function disposeDialog() {
     $$("DIV.dialog").each(function(div) {
         if (div.visible() && div.getOpacity() == 1)
-            div.fade({ duration: 0.2 });
+            jQuery(div).fadeOut('fast');
     });
     if (dialogsStack.length > 0) {
         // Show the next dialog box
@@ -1989,20 +2154,17 @@ function disposeDialog() {
         dialogsStack.splice(0, 1);
         dialogFcn.delay(0.2);
     }
-    else {
-        var bgFade = Effect.Fade('bgDialogDiv', { duration: 0.2 });
+    else if ($('bgDialogDiv')) {
         // By the end the background fade out, a new dialog
         // may need to be displayed.
-        _disposeDialog.delay(0.1, bgFade);
+        jQuery('#bgDialogDiv').fadeOut('fast', _disposeDialog);
     }
 }
 
-function _disposeDialog(bgEffect) {
+function _disposeDialog() {
     if (dialogsStack.length) {
         var div = $("bgDialogDiv");
-        bgEffect.cancel();
-        div.show();
-        div.appear({ duration: 0.2, to: 0.3 });
+        jQuery(div).fadeIn(100);
         var dialogFcn = dialogsStack.first();
         dialogsStack.splice(0, 1);
         dialogFcn();
